@@ -10,16 +10,18 @@ import typing_extensions
 
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_iot._jsii
+import aws_cdk.aws_kinesisfirehose._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_logs._jsii
+import aws_cdk.aws_s3._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-iot-actions",
-    "1.132.0",
+    "1.134.0",
     __name__[0:-6],
-    "aws-iot-actions@1.132.0.jsii.tgz",
+    "aws-iot-actions@1.134.0.jsii.tgz",
 )
 
 __all__ = [
